theca

Struct Profile

pub struct Profile {
    pub encrypted: bool,
    pub notes: Vec<Item>,
}
Main container of a theca profile file

Fields

encrypted: boolnotes: Vec<Item>

Implementations

Source

impl Profile

pub fn new( profile_name: &str, profile_folder: &str, key: &str, new_profile: bool, encrypted: bool, yes: bool, ) -> Result<(Profile, u64)>

setup a Profile struct based on the command line arguments

pub fn clear(&mut self, yes: bool) -> Result<()>

remove all notes from the profile

pub fn save_to_file(&mut self, args: &Args, fingerprint: &u64) -> Result<()>

save the profile back to file (either plaintext or encrypted)

pub fn transfer_note(&mut self, args: &Args) -> Result<()>

transfer a note from the profile to another profile

pub fn add_note( &mut self, title: &str, body: &[String], status: Option<Status>, use_stdin: bool, use_editor: bool, print_msg: bool, ) -> Result<()>

add a item to the profile

pub fn delete_note(&mut self, id: &[usize])

delete an item from the profile

pub fn edit_note( &mut self, id: usize, title: &str, body: &[String], status: Option<Status>, use_stdin: bool, flags: BoolFlags, ) -> Result<()>

edit an item in the profile

pub fn stats(&mut self, name: &str) -> Result<()>

print information about the profile

pub fn view_note( &mut self, id: usize, json: bool, condensed: bool, ) -> Result<()>

print a full item

pub fn list_notes( &mut self, limit: usize, flags: BoolFlags, status: Option<Status>, ) -> Result<()>

print all notes in the profile

pub fn search_notes( &mut self, pattern: &str, limit: usize, flags: BoolFlags, status: Option<Status>, ) -> Result<()>

print notes search for in the profile